@@ -199,7 +199,7 @@ static int mirw_hyperslab_raw(int opcode,
     return MI_LOG_ERROR(MI2_MSG_GENERIC,"Trying to write to a volume thumbnail");
   }
 
-  sprintf(path, MI_ROOT_PATH "/image/%d/image", volume->selected_resolution);
+  snprintf(path, sizeof(path), MI_ROOT_PATH "/image/%d/image", volume->selected_resolution);
   /*printf("Using:%s\n",path);*/
   
   /* Open the dataset with the specified path
@@ -411,7 +411,7 @@ static int mirw_hyperslab_icv(int opcode,
     return MI_LOG_ERROR(MI2_MSG_GENERIC,"Trying to write to a volume thumbnail");
   }
   
-  sprintf(path, MI_ROOT_PATH "/image/%d/image", volume->selected_resolution);
+  snprintf(path, sizeof(path), MI_ROOT_PATH "/image/%d/image", volume->selected_resolution);
   /*printf("Using:%s\n",path);*/
   
   /* Open the dataset with the specified path
@@ -895,7 +895,7 @@ static int mirw_hyperslab_normalized(int opcode,
     return (MI_ERROR);
   }
   
-  sprintf(path, MI_ROOT_PATH "/image/%d/image", volume->selected_resolution);
+  snprintf(path, sizeof(path), MI_ROOT_PATH "/image/%d/image", volume->selected_resolution);
 
   /* Open the dataset with the specified path
   */
